@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  * SPDX-FileCopyrightText: 2021-2022 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
@@ -47,6 +47,8 @@ void Database::closeDatabase(const QString &connectionName)
 
 bool Database::migrate()
 {
+    setWalMode();
+
     int dbversion = version();
     if (dbversion < 1)
         TRUE_OR_RETURN(migrateTo1());
@@ -200,6 +202,26 @@ int Database::version()
     return -1;
 }
 
+void Database::setWalMode()
+{
+    bool ok = false;
+    QSqlQuery query;
+    query.prepare(QStringLiteral("PRAGMA journal_mode;"));
+    execute(query);
+    if (query.next()) {
+        ok = (query.value(0).toString() == QStringLiteral("wal"));
+    }
+
+    if (!ok) {
+        query.prepare(QStringLiteral("PRAGMA journal_mode=WAL;"));
+        execute(query);
+        if (query.next()) {
+            ok = (query.value(0).toString() == QStringLiteral("wal"));
+        }
+        qDebug() << "Activating WAL mode on database:" << (ok ? "ok" : "not ok!");
+    }
+}
+
 void Database::cleanup()
 {
     // TODO: create database sanity checks, or, alternatively, create database scrub routine
