@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  * SPDX-FileCopyrightText: 2021-2022 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
@@ -37,6 +37,7 @@ public:
     Q_INVOKABLE void fetchAll();
     Q_INVOKABLE QString image(const QString &url);
     Q_INVOKABLE QNetworkReply *download(const QString &url, const QString &fileName) const;
+    void getRedirectedUrl(const QUrl &url);
 
     QNetworkReply *get(QNetworkRequest &request) const;
     QNetworkReply *post(QNetworkRequest &request, const QByteArray &data) const;
@@ -60,6 +61,7 @@ Q_SIGNALS:
 
     void error(Error::Type type, const QString &url, const QString &id, const int errorId, const QString &errorString, const QString &title);
     void downloadFinished(QString url) const;
+    void foundRedirectedUrl(const QUrl &url, const QUrl &newUrl);
 
 private:
     Fetcher();
