@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2021 Bart De Vries <bart@mogwai.be>
+ * SPDX-FileCopyrightText: 2021-2023 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -13,7 +13,7 @@
 #include "entry.h"
 
 EpisodeModel::EpisodeModel(QObject *parent)
-    : QAbstractListModel(parent)
+    : AbstractEpisodeModel(parent)
 {
     // When feed is updated, the entire model needs to be reset because we
     // cannot know where the new entries will be inserted into the list (or that
@@ -31,29 +31,25 @@ EpisodeModel::EpisodeModel(QObject *parent)
 QVariant EpisodeModel::data(const QModelIndex &index, int role) const
 {
     switch (role) {
-    case EntryRole:
+    case AbstractEpisodeModel::Roles::TitleRole:
+        return QVariant::fromValue(m_titles[index.row()]);
+    case AbstractEpisodeModel::Roles::EntryRole:
         return QVariant::fromValue(DataManager::instance().getEntry(m_entryIds[index.row()]));
-    case IdRole:
+    case AbstractEpisodeModel::Roles::IdRole:
         return QVariant::fromValue(m_entryIds[index.row()]);
-    case ReadRole:
+    case AbstractEpisodeModel::Roles::ReadRole:
         return QVariant::fromValue(m_read[index.row()]);
-    case NewRole:
+    case AbstractEpisodeModel::Roles::NewRole:
         return QVariant::fromValue(m_new[index.row()]);
+    case AbstractEpisodeModel::Roles::ContentRole:
+        return QVariant::fromValue(m_contents[index.row()]);
+    case AbstractEpisodeModel::Roles::FeedNameRole:
+        return QVariant::fromValue(m_feedNames[index.row()]);
     default:
         return QVariant();
     }
 }
 
-QHash<int, QByteArray> EpisodeModel::roleNames() const
-{
-    return {
-        {EntryRole, "entry"},
-        {IdRole, "id"},
-        {ReadRole, "read"},
-        {NewRole, "new"},
-    };
-}
-
 int EpisodeModel::rowCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent)
@@ -65,12 +61,18 @@ void EpisodeModel::updateInternalState()
     m_entryIds.clear();
     m_read.clear();
     m_new.clear();
+    m_titles.clear();
+    m_feedNames.clear();
+
     QSqlQuery query;
-    query.prepare(QStringLiteral("SELECT id, read, new FROM Entries ORDER BY updated DESC;"));
+    query.prepare(QStringLiteral("SELECT id, read, new, title, content, feed FROM Entries ORDER BY updated DESC;"));
     Database::instance().execute(query);
     while (query.next()) {
         m_entryIds += query.value(QStringLiteral("id")).toString();
         m_read += query.value(QStringLiteral("read")).toBool();
         m_new += query.value(QStringLiteral("new")).toBool();
+        m_titles += query.value(QStringLiteral("title")).toString();
+        m_contents += query.value(QStringLiteral("content")).toString();
+        m_feedNames += DataManager::instance().getFeed(query.value(QStringLiteral("feed")).toString())->name();
     }
 }
